aboutsummaryrefslogtreecommitdiff
path: root/ShiftOS.WinForms/Properties/Resources.Designer.cs
diff options
context:
space:
mode:
authorMichael <[email protected]>2017-06-11 08:21:41 -0400
committerMichael <[email protected]>2017-06-11 08:21:47 -0400
commit7ec048fe8536c9757eda47801af07956b826466d (patch)
treebcc0588ae5509ede6d7e916118040eae828e4600 /ShiftOS.WinForms/Properties/Resources.Designer.cs
parent997a81457ebb6d6523c36ca552cee143e0d92244 (diff)
downloadshiftos_thereturn-7ec048fe8536c9757eda47801af07956b826466d.tar.gz
shiftos_thereturn-7ec048fe8536c9757eda47801af07956b826466d.tar.bz2
shiftos_thereturn-7ec048fe8536c9757eda47801af07956b826466d.zip
More menu work.
Diffstat (limited to 'ShiftOS.WinForms/Properties/Resources.Designer.cs')
-rw-r--r--ShiftOS.WinForms/Properties/Resources.Designer.cs21
1 files changed, 16 insertions, 5 deletions
diff --git a/ShiftOS.WinForms/Properties/Resources.Designer.cs b/ShiftOS.WinForms/Properties/Resources.Designer.cs
index 0386237..137db4b 100644
--- a/ShiftOS.WinForms/Properties/Resources.Designer.cs
+++ b/ShiftOS.WinForms/Properties/Resources.Designer.cs
@@ -1092,9 +1092,9 @@ namespace ShiftOS.WinForms.Properties {
/// {
/// Company: &quot;Shiftcast&quot;,
/// Name: &quot;NetXtreme Hyper Edition&quot;,
- /// CostPerMonth: 1500,
+ /// CostPerMonth: 150,
/// DownloadSpeed: 524288, //512 kb/s
/// Description: &quot;It&apos;s time to supercharge your Shif [rest of string was truncated]&quot;;.
/// </summary>
internal static string ShiftnetServices {
get {
@@ -1113,9 +1113,10 @@ namespace ShiftOS.WinForms.Properties {
/// Category: &quot;Enhancements&quot;,
/// },
/// {
- /// Name: &quot;Shift Progress Bar&quot;,
- /// Cost: 150,
- /// Description: &quot;Want to customize the look of all ShiftOS Progress Bars? Buy this upgrade today and you&apos;ll get the ability to set the foreground an [rest of string was truncated]&quot;;.
+ /// Name: &quot;Icon Manager&quot;,
+ /// Cost: 450,
+ /// Description: &quot;This tool allows you to add and edit application icons within ShiftOS for the small prive of 450 Codepoints!&quot;,
+ /// Dependencies: &quot;skinning [rest of string was truncated]&quot;;.
/// </summary>
internal static string Shiftorium {
get {
@@ -1136,6 +1137,16 @@ namespace ShiftOS.WinForms.Properties {
/// <summary>
/// Looks up a localized resource of type System.Drawing.Bitmap.
/// </summary>
+ internal static System.Drawing.Bitmap ShiftOSFull {
+ get {
+ object obj = ResourceManager.GetObject("ShiftOSFull", resourceCulture);
+ return ((System.Drawing.Bitmap)(obj));
+ }
+ }
+
+ /// <summary>
+ /// Looks up a localized resource of type System.Drawing.Bitmap.
+ /// </summary>
internal static System.Drawing.Bitmap SnakeyBG {
get {
object obj = ResourceManager.GetObject("SnakeyBG", resourceCulture);
@@ -1092,9 +1092,9 @@ namespace ShiftOS.WinForms.Properties {
/// DownloadSpeed: 524288, //512 kb/s
- /// Description: &quot;It&apos;s time to supercharge your Shif [rest of string was truncated]&quot;;.
+ /// Description: &quot;It&apos;s time to supercharge your Shift [rest of string was truncated]&quot;;.
/// </summary>
internal static string ShiftnetServices {